ozi-new webui

### {TRANSLATION('adm-disclaimer-title')}

×
{TRANSLATION('adm-disclaimer-text')}

# {TRANSLATION('web-core-metadata')}

{TRANSLATION('pro-name')}

#####

{TRANSLATION('pro-summary')}

#####

{TRANSLATION('pro-keywords')}

#####

{TRANSLATION('pro-author')}

#####

{TRANSLATION('pro-author-email')}

#####

{TRANSLATION('pro-maintainer')}

#####

{TRANSLATION('pro-maintainer-email')}

#####

# {TRANSLATION('edit-menu-btn-license')}

{TRANSLATION('pro-license-expression')}
{TRANSLATION('edit-menu-btn-license-exception')}
{TRANSLATION('pro-license')}
{TRANSLATION('edit-menu-btn-license-file')}

# {TRANSLATION('term-classifier')} {TRANSLATION('term-metadata')}

{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-audience'))}
{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-environment'))}
{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-framework'))}
{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-topic'))}
{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-status'))}
{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-language'))}